@@ -1,7 +1,5 @@
 """Experimental module to automatically install Friendly
 as a replacement for the standard traceback in IPython."""
-import inspect
-
 try:
     from IPython.core import interactiveshell as shell  # noqa
     from IPython.core import compilerop  # noqa
@@ -30,17 +28,6 @@ try:
 except Exception:  # noqa
     pass
 
-# The following is used to extract the contents of code blocks
-# so as to shorten name of code block "files" for SyntaxError
-# cases - since SyntaxErrors do not generate frames.
-frames = inspect.getouterframes(inspect.currentframe())
-session.ipython_frame = None
-for frame_info in frames:
-    frame = frame_info.frame
-    if "In" in frame.f_locals or "In" in frame.f_globals:
-        session.ipython_frame = frame
-        break
-
 colorama.deinit()
 colorama.init(convert=False, strip=False)
 session.ipython_prompt = True
